@@ -7,7 +7,9 @@ init(convert=True)
 __app_name__ = "pie-manager"
 
 def parent_dir(path: str):
-    return os.path.abspath(os.path.join(path, os.pardir))
+    return_ = os.path.abspath(os.path.join(path, os.pardir))
+    print("Installing pie in '" + return_ + "'.")
+    return return_
 
 def main():
     pie = shutil.which("pie")
@@ -52,7 +54,7 @@ def many_in_check(*list, iterable=None):
     return False
 
 def entry_point():
-    if many_in_check("-U", "--upgrade", "--install", "-I", iterable=(i.lower() for i in sys.argv)):
+    if many_in_check("-U", "--upgrade", "--install", "-I", iterable=(i for i in sys.argv)):
         main()
     else:
         print(Fore.RED + "Please use '--upgrade' '-U', '--install', '-I' to install/upgrade pie." + Fore.RESET)
